==> mypy_boto3_budgets-0.2.2-py3-none-any.whl: mypy_boto3_budgets/helpers.py <==
"Helper functions for budgets service"

from typing import Any, Dict, Union
import boto3
from boto3.session import Session
from botocore.config import Config
from mypy_boto3_budgets.client import Client
from mypy_boto3_budgets.paginator import (
    DescribeBudgetsPaginator,
    DescribeNotificationsForBudgetPaginator,
    DescribeSubscribersForNotificationPaginator,
)

# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def boto3_client(
    session: Session = None,
    region_name: str = None,
    api_version: str = None,
    use_ssl: bool = None,
    verify: Union[str, bool] = None,
    endpoint_url: str = None,
    aws_access_key_id: str = None,
    aws_secret_access_key: str = None,
    aws_session_token: str = None,
    config: Config = None,
) -> Client:
    """
    Equivalent of `boto3.client('budgets')`, returns a correct type.
    """
    kwargs: Dict[str, Any] = {}
    if region_name is not None:
        kwargs["region_name"] = region_name
    if api_version is not None:
        kwargs["api_version"] = api_version
    if use_ssl is not None:
        kwargs["use_ssl"] = use_ssl
    if verify is not None:
        kwargs["verify"] = verify
    if endpoint_url is not None:
        kwargs["endpoint_url"] = endpoint_url
    if aws_access_key_id is not None:
        kwargs["aws_access_key_id"] = aws_access_key_id
    if aws_secret_access_key is not None:
        kwargs["aws_secret_access_key"] = aws_secret_access_key
    if aws_session_token is not None:
        kwargs["aws_session_token"] = aws_session_token
    if config is not None:
        kwargs["config"] = config
    if session is not None:
        return session.client("budgets", **kwargs)
    return boto3.client("budgets", **kwargs)


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_budgets_paginator(client: Client) -> DescribeBudgetsPaginator:
    """
    Equivalent of `client.get_paginator('describe_budgets')`, returns a correct type.
    """
    return client.get_paginator("describe_budgets")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_notifications_for_budget_paginator(
    client: Client,
) -> DescribeNotificationsForBudgetPaginator:
    """
    Equivalent of `client.get_paginator('describe_notifications_for_budget')`, returns a correct type.
    """
    return client.get_paginator("describe_notifications_for_budget")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_subscribers_for_notification_paginator(
    client: Client,
) -> DescribeSubscribersForNotificationPaginator:
    """
    Equivalent of `client.get_paginator('describe_subscribers_for_notification')`, returns a correct type.
    """
    return client.get_paginator("describe_subscribers_for_notification")

==> mypy_boto3_budgets-1.10.28-py3-none-any.whl: mypy_boto3_budgets/helpers.py <==
"Helper functions for budgets service"

from typing import Any, Dict, Union
import boto3
from boto3.session import Session
from botocore.config import Config
from mypy_boto3_budgets.client import Client
from mypy_boto3_budgets.paginator import (
    DescribeBudgetsPaginator,
    DescribeNotificationsForBudgetPaginator,
    DescribeSubscribersForNotificationPaginator,
)

# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def boto3_client(
    session: Session = None,
    region_name: str = None,
    api_version: str = None,
    use_ssl: bool = None,
    verify: Union[str, bool] = None,
    endpoint_url: str = None,
    aws_access_key_id: str = None,
    aws_secret_access_key: str = None,
    aws_session_token: str = None,
    config: Config = None,
) -> Client:
    """
    Equivalent of `boto3.client('budgets')`, returns a correct type.
    """
    kwargs: Dict[str, Any] = {}
    if region_name is not None:
        kwargs["region_name"] = region_name
    if api_version is not None:
        kwargs["api_version"] = api_version
    if use_ssl is not None:
        kwargs["use_ssl"] = use_ssl
    if verify is not None:
        kwargs["verify"] = verify
    if endpoint_url is not None:
        kwargs["endpoint_url"] = endpoint_url
    if aws_access_key_id is not None:
        kwargs["aws_access_key_id"] = aws_access_key_id
    if aws_secret_access_key is not None:
        kwargs["aws_secret_access_key"] = aws_secret_access_key
    if aws_session_token is not None:
        kwargs["aws_session_token"] = aws_session_token
    if config is not None:
        kwargs["config"] = config
    if session is not None:
        return session.client("budgets", **kwargs)
    return boto3.client("budgets", **kwargs)


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_budgets_paginator(client: Client) -> DescribeBudgetsPaginator:
    """
    Equivalent of `client.get_paginator('describe_budgets')`, returns a correct type.
    """
    return client.get_paginator("describe_budgets")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_notifications_for_budget_paginator(
    client: Client,
) -> DescribeNotificationsForBudgetPaginator:
    """
    Equivalent of `client.get_paginator('describe_notifications_for_budget')`, returns a correct
    type.
    """
    return client.get_paginator("describe_notifications_for_budget")


# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
def get_describe_subscribers_for_notification_paginator(
    client: Client,
) -> DescribeSubscribersForNotificationPaginator:
    """
    Equivalent of `client.get_paginator('describe_subscribers_for_notification')`, returns a correct
    type.
    """
    return client.get_paginator("describe_subscribers_for_notification")
